@@ -5,9 +5,12 @@
  * This source code is under the GNU Public License (GPL).  See
  * LICENSE for details.
  *
- * $Id: main.c,v 1.12 1999/04/21 01:40:14 jelson Exp $
+ * $Id: main.c,v 1.13 2001/02/26 23:01:30 jelson Exp $
  *
  * $Log: main.c,v $
+ * Revision 1.13  2001/02/26 23:01:30  jelson
+ * Added patch for -r option
+ *
  * Revision 1.12  1999/04/21 01:40:14  jelson
  * DLT_NULL fixes, u_char fixes, additions to configure.in, man page update
  *
@@ -40,7 +43,7 @@
  *
  */
 
-static char *cvsid = "$Id: main.c,v 1.12 1999/04/21 01:40:14 jelson Exp $";
+static char *cvsid = "$Id: main.c,v 1.13 2001/02/26 23:01:30 jelson Exp $";
 
 #define __MAIN_C__
 
@@ -63,7 +66,7 @@ void print_usage(char *progname)
   fprintf(stderr, "%s version %s by Jeremy Elson <jelson@circlemud.org>\n\n",
 		 PACKAGE, VERSION);
   fprintf(stderr, "usage: %s [-chpsv] [-b max_bytes] [-d debug_level] [-f max_fds]\n", progname);
-  fprintf(stderr, "          [-i iface] [expression]\n\n");
+  fprintf(stderr, "          [-i iface] [-w file] [expression]\n\n");
   fprintf(stderr, "        -b: max number of bytes per flow to save\n");
   fprintf(stderr, "        -c: console print only (don't create files)\n");
   fprintf(stderr, "        -d: debug level; default is %d\n", DEFAULT_DEBUG_LEVEL);
@@ -72,6 +75,7 @@ void print_usage(char *progname)
   fprintf(stderr, "        -i: network interface on which to listen\n");
   fprintf(stderr, "            (type \"ifconfig -a\" for a list of interfaces)\n");
   fprintf(stderr, "        -p: don't use promiscuous mode\n");
+  fprintf(stderr, "        -r: read packets from tcpdump output file\n");
   fprintf(stderr, "        -s: strip non-printable characters (change to '.')\n");
   fprintf(stderr, "        -v: verbose operation equivalent to -d 10\n");
   fprintf(stderr, "expression: tcpdump-like filtering expression\n");
@@ -79,6 +83,13 @@ void print_usage(char *progname)
 }
 
 
+RETSIGTYPE terminate(int sig)
+{
+  DEBUG(1) ("terminating");
+  exit(0); /* libpcap uses onexit to clean up */
+}
+
+
 int main(int argc, char *argv[])
 {
   extern int optind;
@@ -89,6 +100,7 @@ int main(int argc, char *argv[])
   int need_usage = 0;
 
   char *device = NULL;
+  char *infile = NULL;
   char *expression = NULL;
   pcap_t *pd;
   struct bpf_program fcode;
@@ -98,7 +110,7 @@ int main(int argc, char *argv[])
 
   opterr = 0;
 
-  while ((arg = getopt(argc, argv, "b:cd:f:hi:psv")) != EOF) {
+  while ((arg = getopt(argc, argv, "b:cd:f:hi:pr:sv")) != EOF) {
     switch (arg) {
     case 'b':
       if ((bytes_per_flow = atoi(optarg)) < 0) {
@@ -140,6 +152,9 @@ int main(int argc, char *argv[])
       no_promisc = 1;
       DEBUG(10) ("NOT turning on promiscuous mode");
       break;
+    case 'r':
+      infile = optarg;
+      break;
     case 'v':
       debug_level = 10;
       break;
@@ -160,23 +175,34 @@ int main(int argc, char *argv[])
   DEBUG(10) ("%s version %s by Jeremy Elson <jelson@circlemud.org>",
 	     PACKAGE, VERSION);
 
-  /* if the user didn't specify a device, try to find a reasonable one */
-  if (device == NULL)
-    if ((device = pcap_lookupdev(error)) == NULL)
+  if (infile != NULL) {
+    /* Since we don't need network access, drop root privileges */
+    setuid(getuid());
+
+    /* open the capture file */
+    if ((pd = pcap_open_offline(infile, error)) == NULL)
       die(error);
 
-  /* make sure we can open the device */
-  if ((pd = pcap_open_live(device, SNAPLEN, !no_promisc, 1000, error)) == NULL)
-    die(error);
+    /* get the handler for this kind of packets */
+    dlt = pcap_datalink(pd);
+    handler = find_handler(dlt, infile);
+  } else {
+    /* if the user didn't specify a device, try to find a reasonable one */
+    if (device == NULL)
+      if ((device = pcap_lookupdev(error)) == NULL)
+	die(error);
 
-  /* drop root privileges - we don't need them any more */
-  setuid(getuid());
+    /* make sure we can open the device */
+    if ((pd = pcap_open_live(device, SNAPLEN, !no_promisc, 1000, error)) == NULL)
+      die(error);
 
-  /* remember what datalink type the selected network interface is */
-  dlt = pcap_datalink(pd);
+    /* drop root privileges - we don't need them any more */
+    setuid(getuid());
 
-  /* get the handler for this network interface */
-  handler = find_handler(dlt, device);
+    /* get the handler for this kind of packets */
+    dlt = pcap_datalink(pd);
+    handler = find_handler(dlt, device);
+  }
 
   /* get the user's expression out of argv */
   expression = copy_argv(&argv[optind]);
@@ -222,8 +248,15 @@ int main(int argc, char *argv[])
   /* initialize our flow state structures */
   init_flow_state();
 
+  /* set up signal handlers for graceful exit (pcap uses onexit to put
+     interface back into non-promiscuous mode */
+  portable_signal(SIGTERM, terminate);
+  portable_signal(SIGINT, terminate);
+  portable_signal(SIGHUP, terminate);
+
   /* start listening! */
-  DEBUG(1) ("listening on %s", device);
+  if (infile == NULL)
+    DEBUG(1) ("listening on %s", device);
   if (pcap_loop(pd, -1, handler, NULL) < 0)
     die(pcap_geterr(pd));
 
