@@ -5,9 +5,13 @@
  * This source code is under the GNU Public License (GPL).  See
  * LICENSE for details.
  *
- * $Id: tcpflow.h,v 1.8 1999/04/21 01:40:16 jelson Exp $
+ * $Id: tcpflow.h,v 1.9 2000/12/08 07:32:39 jelson Exp $
  *
  * $Log: tcpflow.h,v $
+ * Revision 1.9  2000/12/08 07:32:39  jelson
+ * Took out the (broken) support for fgetpos/fsetpos.  Now we always simply
+ * use fseek and ftell.
+ *
  * Revision 1.8  1999/04/21 01:40:16  jelson
  * DLT_NULL fixes, u_char fixes, additions to configure.in, man page update
  *
@@ -59,7 +63,7 @@ typedef struct flow_state_struct {
   flow_t flow;			/* Description of this flow */
   tcp_seq isn;			/* Initial sequence number we've seen */
   FILE *fp;			/* Pointer to file storing this flow's data */
-  fpos_t pos;			/* Current write position in fp */
+  long pos;			/* Current write position in fp */
   int flags;			/* Don't save any more data from this flow */
   int last_access;		/* "Time" of last access */
 } flow_state_struct;
@@ -97,6 +101,7 @@ void init_debug(char *argv[]);
 void *check_malloc(size_t size);
 char *flow_filename(flow_t flow);
 int get_max_fds(void);
+RETSIGTYPE (*portable_signal(int signo, RETSIGTYPE (*func)(int)))(int);
 void debug_real(char *fmt, ...)
 #ifdef __GNUC__
                 __attribute__ ((format (printf, 1, 2)))
